@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply melodic inversion to a series of notes
 
-our $VERSION = '0.0500';
+our $VERSION = '0.0501';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
@@ -128,13 +128,13 @@ Music::MelodicDevice::Inversion - Apply melodic inversion to a series of notes
 
 =head1 VERSION
 
-version 0.0500
+version 0.0501
 
 =head1 SYNOPSIS
 
   use Music::MelodicDevice::Inversion;
 
-  my @notes = qw(C4 E4 D4 G4 C5);
+  my @notes = qw(C4 E4 D4 G4 C5); # either named notes or midinums
 
   # Chromatic
   my $md = Music::MelodicDevice::Inversion->new;
@@ -150,8 +150,8 @@ version 0.0500
 
 C<Music::MelodicDevice::Inversion> applies intervallic melodic
 inversions, both chromatic or diatonic, to a series of ISO formatted
-notes.  Basically, this flips a melody upside-down given a starting
-note.
+or "midinum" notes.  Basically, this flips a melody upside-down given
+a starting note.
 
 While there are a couple modules on CPAN that do various versions of
 melodic inversion, none appear to apply to an arbitrary series of
